<h1 align="center">
  <img src="https://raw.githubusercontent.com/uukelele-scratch/hybridoma/refs/heads/main/.github/assets/hybridoma.png" height="300">
  <br>
  Hybridoma
</h1>
<h3 align="center">Write Python, get a reactive frontend - no JS framework required</h3>

<h3 align="center">
  <img src="https://img.shields.io/github/actions/workflow/status/uukelele-scratch/hybridoma/publish.yml" alt="GitHub Actions Workflow Status">
  <img src="https://img.shields.io/github/issues/uukelele-scratch/hybridoma" alt="GitHub Issues or Pull Requests">
  <img src="https://img.shields.io/github/issues-pr/uukelele-scratch/hybridoma" alt="GitHub Issues or Pull Requests">
  <img src="https://img.shields.io/pypi/l/hybridoma" alt="PyPI - License">
  <img src="https://img.shields.io/github/stars/uukelele-scratch/hybridoma" alt="GitHub Repo stars">
  <img src="https://img.shields.io/pypi/v/hybridoma" alt="PyPI - Version">
</h3>

***

- **[Documentation](https://github.com/uukelele-scratch/hybridoma/wiki)**
- **[Issues](https://github.com/uukelele-scratch/hybridoma/issues)**
- **[GitHub](https://github.com/uukelele-scratch/hybridoma)**
- **[PyPI](https://pypi.org/project/hybridoma)**
